Struct IndexInfo

pub struct IndexInfo<T: Config<I>, I: 'static = ()> {
    principal: AssetOf<T, I>,
    capital: T::Shares,
    entries: Entries<T, I>,
}
Represents an index containing multiple entries.

An IndexInfo tracks the overall capital, total balance, and the entries themselves.

Fields

principal: AssetOf<T, I>

Total asset depositted to this index

This does not qualify as real-time value of the index, since entries are finite digests that should be queried for such cases.

capital: T::Shares

Total shares/capital across all entries in this index

entries: Entries<T, I>

The collection of entries making up this index

Implementations

Source

impl<T: Config<I>, I: 'static> IndexInfo<T, I>

pub(crate) fn new(entries: &mut Entries<T, I>) -> Result<Self, DispatchError>

Creates a new IndexInfo from a collection of entries.

This function calculates the total capital by summing the shares of all entries. It retains only entries of non-zero shares.

Returns DispatchError if any of invariant fails

  • Total Capital cannot be zero
  • Entries should not be empty
pub fn capital(&self) -> T::Shares

Returns the index’s capital - total shares.

pub fn principal(&self) -> AssetOf<T, I>

Returns the index’s principal, i.e. the total amount deposited by proprietors.

pub fn entries(&self) -> Vec<EntryInfo<T, I>>

Returns the index’s entries vector list.

pub fn reveal_entries(&self) -> Entries<T, I>

Reveal the actual entries Entries

pub fn entry_exists(&self, entry: &EntryDigest<T>) -> DispatchResult

Checks if an entry of digest exists in the index.

pub(crate) fn set_balance(&mut self, principal: AssetOf<T, I>)

Sets the index principal to the provided value, replacing the existing balance.