pub struct PoolInfo<T: Config<I>, I: 'static = ()> {
balance_of: LazyBalanceOf<T, I>,
capital: T::Shares,
commission: T::Commission,
slots: Slots<T, I>,
}Expand description
Represents a managed pool derived from an index.
PoolInfo aggregates capital, commission, and the collection of slots,
each of which represents a portion of the pool linked to underlying entries.
Unlike indexes, pools are mutable and can have their slot balances adjusted dynamically.
Pools are created from an IndexInfo (or Entries), allowing the
shares of each entry to be translated into slots within the pool.
Pool’s slot shares/variants can then be adjusted over time, while the pool’s commission and structure remain consistent.
Fields
balance_of: LazyBalanceOf<T, I>Real-time balance of the pool.
Stored as LazyBalanceOf which allows efficient updates and tracking
proprietor depositted balances internally within itself at higher level.
capital: T::SharesTotal capital of the pool.
Computed as the sum of all shares in the pool’s slots. Represents the total weight or stake across all slots.
commission: T::CommissionCommission rate charged by the pool manager.
The manager earns this percentage of rewards or profits generated by the pool.
slots: Slots<T, I>Collection of slots representing the underlying assets or commitments.
Each slot corresponds to an entry from the index that formed
this pool. Slots track individual shares, its deposit receipt,
and disposition Disposition.
Implementations
Sourceimpl<T: Config<I>, I: 'static> PoolInfo<T, I>
impl<T: Config<I>, I: 'static> PoolInfo<T, I>
Sourcepub(crate) fn new(
index_entries: Entries<T, I>,
commission: T::Commission,
) -> Result<Self, DispatchError>
pub(crate) fn new( index_entries: Entries<T, I>, commission: T::Commission, ) -> Result<Self, DispatchError>
Sourcepub fn balance(&self) -> LazyBalanceOf<T, I>
pub fn balance(&self) -> LazyBalanceOf<T, I>
Returns the pool’s lazy balance.
Sourcepub(crate) fn set_balance(&mut self, balance: LazyBalanceOf<T, I>)
pub(crate) fn set_balance(&mut self, balance: LazyBalanceOf<T, I>)
Set the pool balance usually only after release.
Sourcepub fn capital(&self) -> T::Shares
pub fn capital(&self) -> T::Shares
Returns the pool’s total capital i.e., total shares of all slots.
Sourcepub fn commission(&self) -> T::Commission
pub fn commission(&self) -> T::Commission
Returns the pool’s commission i.e., manager’s share while resolving the pool’s commit.
Sourcepub(crate) fn balance_reset(&mut self)
pub(crate) fn balance_reset(&mut self)
Resets the pools’s top-level lazy balance.
This lazy balance acts like a pseudo-direct-digest for proprietors structurally for pool-commitments.
Sourcepub(crate) fn set_slot_commit(
&mut self,
digest: &SlotDigest<T>,
commit: CommitInstance<T, I>,
) -> Result<(), DispatchError>
pub(crate) fn set_slot_commit( &mut self, digest: &SlotDigest<T>, commit: CommitInstance<T, I>, ) -> Result<(), DispatchError>
Replaces the commit instance of the slot identified by digest
by delegating to the underlying slots.
Sourcepub(crate) fn remove_slot(&mut self, slot: &SlotDigest<T>) -> DispatchResult
pub(crate) fn remove_slot(&mut self, slot: &SlotDigest<T>) -> DispatchResult
Removes an existing slot from the pool.
Unlike indexes which are immutable, pools are mutable hence requires slot management via higher-structures.
Returns DispatchError otherwise.
Sourcepub fn slot_exists(&self, slot: &SlotDigest<T>) -> DispatchResult
pub fn slot_exists(&self, slot: &SlotDigest<T>) -> DispatchResult
Checks if a slot of digest exists in the pool.