pub struct SlotInfo<T: Config<I>, I: 'static = ()> {
digest: SlotDigest<T>,
shares: T::Shares,
commit: CommitInstance<T, I>,
variant: T::Position,
}Expand description
Represents a slot within a pool, derived from an index entry.
A SlotInfo tracks the underlying digest, the allocated shares, the
slot’s single CommitInstance (a collective receipt)
and the variant/disposition. It is primarily used when creating or
managing pools derived from index entries.
Fields
digest: SlotDigest<T>Unique identifier for the slot
Shares allocated to this slot
commit: CommitInstance<T, I>Commit-Instance associated with this slot
Since pools collectively manages funds, slots also inherit such behaviour. Hence it acts similar to a proprietor holding a deposit receipt from digest for their commitment.
variant: T::PositionDisposition of this slot (e.g., Affirmative, Contrary, Awaiting)
Implementations
Sourceimpl<T: Config<I>, I: 'static> SlotInfo<T, I>
impl<T: Config<I>, I: 'static> SlotInfo<T, I>
Returns the pool’s slot’s total shares.
Sourcepub fn commit(&self) -> CommitInstance<T, I>
pub fn commit(&self) -> CommitInstance<T, I>
Returns the pool’s slot’s commit-instance (as a pseudo-proprietor).
Sourcepub fn digest(&self) -> SlotDigest<T>
pub fn digest(&self) -> SlotDigest<T>
Returns the pool’s slot’s digest.
Sourcefn set_slot_commit(&mut self, commit: CommitInstance<T, I>)
fn set_slot_commit(&mut self, commit: CommitInstance<T, I>)
Updates the CommitInstance associated with this slot.
This method replaces the existing commit instance with the provided one. It does not perform any validation, aggregation, or merging of commits, the caller is responsible for ensuring correctness and consistency.
Parameters
commit: The newCommitInstanceto associate with this slot.
Invariants
- This operation assumes the slot is already initialized.
- The provided commit should be semantically valid for this slot’s digest, shares, and variant.
Note
This is an internal mutation helper and is not intended to enforce higher-level commitment rules.