pub struct IndexInfo<T: Config<I>, I: 'static = ()> {
principal: AssetOf<T, I>,
capital: T::Shares,
entries: Entries<T, I>,
}Expand description
Represents an index containing multiple entries.
An IndexInfo tracks the overall capital, total balance, and the entries themselves.
Fields
principal: AssetOf<T, I>Total asset depositted to this index
This does not qualify as real-time value of the index, since entries are finite digests that should be queried for such cases.
capital: T::SharesTotal shares/capital across all entries in this index
entries: Entries<T, I>The collection of entries making up this index
Implementations
Sourceimpl<T: Config<I>, I: 'static> IndexInfo<T, I>
impl<T: Config<I>, I: 'static> IndexInfo<T, I>
Sourcepub(crate) fn new(entries: &mut Entries<T, I>) -> Result<Self, DispatchError>
pub(crate) fn new(entries: &mut Entries<T, I>) -> Result<Self, DispatchError>
Creates a new IndexInfo from a collection of entries.
This function calculates the total capital by summing the shares of all entries. It retains only entries of non-zero shares.
Returns DispatchError if any of invariant fails
- Total Capital cannot be zero
- Entries should not be empty
Sourcepub fn principal(&self) -> AssetOf<T, I>
pub fn principal(&self) -> AssetOf<T, I>
Returns the index’s principal, i.e. the total amount deposited by proprietors.
Sourcepub fn reveal_entries(&self) -> Entries<T, I>
pub fn reveal_entries(&self) -> Entries<T, I>
Reveal the actual entries Entries
Sourcepub fn entry_exists(&self, entry: &EntryDigest<T>) -> DispatchResult
pub fn entry_exists(&self, entry: &EntryDigest<T>) -> DispatchResult
Checks if an entry of digest exists in the index.
Sourcepub(crate) fn set_balance(&mut self, principal: AssetOf<T, I>)
pub(crate) fn set_balance(&mut self, principal: AssetOf<T, I>)
Sets the index principal to the provided value, replacing the existing balance.