pub type Digest<T> = <T as Config>::AccountId;Expand description
The primary digest type used to uniquely identify a commitment entity.
This type is reused across direct, index, and pool commitments.
pub type Digest<T> = <T as Config>::AccountId;The primary digest type used to uniquely identify a commitment entity.
This type is reused across direct, index, and pool commitments.